/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Anna
 */

import { type Collection, MongoClient } from "mongodb";
import type { ReminderChannel } from "../models/channel";

const client = new MongoClient(process.env.MONGO_DB_URL ?? "");

const databaseName = "Maribelle";

// eslint-disable-next-line @typescript-eslint/init-declarations -- I need a reference to the collection to insert records
let collection: Collection<ReminderChannel>;

/**
 * Initializes a connection to the database
 * using the environment variable.
 */
async function initializeDatabase(): Promise<void> {
  await client.connect();
  const database = client.db(databaseName);
  collection = database.collection<ReminderChannel>("channel");
}

/**
 * Inserts a new channel into the database.
 * @param channelId - The id of the channel to post in.
 * @param roleId - The id of the role to ping.
 * @param name - The name of the group.
 */
async function insertRecord(channelId: string,
  roleId:    string,
  name: string): Promise<void> {
  const document = { channelId, name, roleId };
  await collection.insertOne(document);
}

/**
 * Closes the connection to the database.
 */
async function closeDatabase(): Promise<void> {
  await client.close();
}

export { closeDatabase, initializeDatabase, insertRecord };
